%define upstream_name HandBrake
%define download %{_builddir}/%{upstream_name}-%{version}/download

Summary:        MPEG-AVC(H.264)/MPEG-4 converter
Name:           handbrake
Version:        1.0.7
Release:        %mkrel 1
License:        GPLv2 and LGPL and LGPLv2.1 and BSD
Group:          Video/Editors and Converters
URL:            https://handbrake.fr/
Source0:        https://download.handbrake.fr/releases/%{version}/%{upstream_name}-%{version}.tar.bz2
Source1:        https://download.handbrake.fr/handbrake/contrib/libav-12.tar.gz
Source2:        https://download.handbrake.fr/handbrake/contrib/libbluray-0.9.3.tar.bz2
Source3:        https://download.handbrake.fr/handbrake/contrib/libdvdnav-5.0.1.tar.bz2
Source4:        https://download.handbrake.fr/handbrake/contrib/libdvdread-5.0.0-6-gcb1ae87.tar.gz
Source5:        https://download.handbrake.fr/contrib/libvpx-1.5.0.tar.bz2
Source6:        https://download.handbrake.fr/contrib/x265_2.1-1.tar.gz

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  yasm
BuildRequires:  bzip2-devel
BuildRequires:  lame-devel
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(webkitgtk-3.0)
BuildRequires:  pkgconfig(x264)
BuildRequires:  pkgconfig(zlib)

#ARM architecture is officially not supported by HandBrake (see https://github.com/HandBrake/HandBrake/issues/538)
#We only exclude ARMv5 since the package still builds on ARMv7.
ExcludeArch: armv5tl

%description
Versatile DVD ripper and video transcoder - command line
HandBrake is a versatile, easy-to-use tool for converting DVDs and other videos
into H.264, MPEG-4, or OGG formatted media. It's particularly useful for making
videos that are compatible with portable video devices such as the Apple
iPod/iPhone.

%prep
%setup -q -n %{upstream_name}-%{version}
%{__mkdir} %download
%{__cp} -t %download %{SOURCE1}
%{__cp} -t %download %{SOURCE2}
%{__cp} -t %download %{SOURCE3}
%{__cp} -t %download %{SOURCE4}
%{__cp} -t %download %{SOURCE5}
%{__cp} -t %download %{SOURCE6}

# Copied from libvpx, in particular that avoids using neon/soft abi on armv7hl
%ifarch %{ix86}
%global vpxtarget x86-linux-gcc
%else
%ifarch	x86_64
%global	vpxtarget x86_64-linux-gcc
%else
%global vpxtarget generic-gnu
%endif
%endif

echo LIBVPX.CONFIGURE.extra += --target=%{vpxtarget} >> contrib/libvpx/module.defs

%build
# This hack was removed in the previous version of the script. It is added again on demand of Florian Hubold
# See https://bugs.mageia.org/show_bug.cgi?id=5502#c20
# On update, when someone forgets to redo the tarball of the contribs libraries, handbrake buildsystem
# will automatically download those, that is objectionable on mageia buildsystema and build should fail
# small hack, proposed by Anssi, to disable accidental automatic downloading of contrib libraries
mkdir -p disable_contrib.fetch-hack

for downloader in wget url; do
  ln -s /bin/false disable_contrib.fetch-hack/${downloader}
done
#add it to PATH so our fake downloaders get picked up from handbrake buildsystem
export PATH=$PWD/disable_contrib.fetch-hack:$PATH

# Tricky pony : the ./configure script doesn't
# know the usual params of configure2_5x
# --disable-fdk-aac option ensure that no non-free
# material is compiled with main sources
%setup_compile_flags
./configure \
        --prefix=%{_prefix} \
        --launch \
        --launch-jobs=0 \
        --verbose \
        --debug=none

%make_build -C build

%install
%make_install -C build

%find_lang ghb

desktop-file-install --vendor="" \
  --remove-category="Application" \
  --remove-key="Encoding" \
  --add-category="AudioVideo;Video;AudioVideoEditing;" \
  --add-category="X-Mageia-CrossDesktop" \
  --dir %buildroot/%_datadir/applications %buildroot/%_datadir/applications/*

%files -f ghb.lang
%defattr(-,root,root)
%doc AUTHORS* COPYING 
%_bindir/*
%_datadir/applications/*
%_datadir/icons/hicolor


%changelog
* Sat Jun 30 2018 adrianomorselli <adrianomorselli> 1.0.7-1uplos2018
- update
